Mesa (master): r600g: also disable transform feedback on cayman

Marek Olšák mareko at kemper.freedesktop.org
Tue Mar 27 17:38:49 PDT 2012


Module: Mesa
Branch: master
Commit: 9773369ab4d1c75965821635f448733edde98636
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=9773369ab4d1c75965821635f448733edde98636

Author: Marek Olšák <maraeo at gmail.com>
Date:   Wed Mar 28 02:21:03 2012 +0200

r600g: also disable transform feedback on cayman

It's said to cause troubles there.
The env var is R600_STREAMOUT again.

---

 src/gallium/drivers/r600/r600_pipe.c |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/src/gallium/drivers/r600/r600_pipe.c b/src/gallium/drivers/r600/r600_pipe.c
index 580b9c1..3ab78ea 100644
--- a/src/gallium/drivers/r600/r600_pipe.c
+++ b/src/gallium/drivers/r600/r600_pipe.c
@@ -814,9 +814,10 @@ struct pipe_screen *r600_screen_create(struct radeon_winsys *ws)
 		rscreen->chip_class = R600;
 	}
 
-	/* XXX streamout is broken on r700 */
-	if (rscreen->chip_class == R700 &&
-	    !debug_get_bool_option("R700_STREAMOUT", FALSE)) {
+	/* XXX streamout is said to be broken on r700 and cayman */
+	if ((rscreen->chip_class == R700 ||
+	     rscreen->chip_class == CAYMAN) &&
+	    !debug_get_bool_option("R600_STREAMOUT", FALSE)) {
 		rscreen->info.r600_has_streamout = false;
 	}
 



More information about the mesa-commit mailing list